conv_spatial: Merge all dataframes into one spatial dataframe. See sf...

Description Usage Arguments Value

View source: R/get-spatial-catch-data.R

Description

This function converts all supplied data frames into a single sf data frame. It also removes points found on land or way out of the fishing area. The Fishing IDs (FIDs) for this filtration were found using mapview::mapview().

Usage

1

Arguments

...

Dataframes to merge. They must all have the columns X and Y

Value

a spatial data frame as described in the sf package


pbs-assess/hakedata documentation built on Jan. 16, 2021, 9:15 p.m.