create_catch_csv_file: Create a CSV file with catch by year and month for a...

Description Usage Arguments

Description

Create a CSV file with catch by year and month for a particular fishery

Usage

1

Arguments

df

The data frame to reduce into a CSV. This will be output from the get_catch() function

fn

Filename for the CSV


pbs-assess/hakedata documentation built on Jan. 16, 2021, 9:15 p.m.