dot-onLoad: When the package is loaded, set ggplot theme to hake theme

Description Usage Arguments

Description

When the package is loaded, set ggplot theme to hake theme

Usage

1
.onLoad(libname, pkgname)

Arguments

libname

See .onLoad()

pkgname

See .onLoad()


pbs-assess/hakedata documentation built on Jan. 16, 2021, 9:15 p.m.