far_point: An sf class POINT which represents a point at the lower...

Description Usage Format

Description

An sf class POINT which represents a point at the lower rightmost part of the fishery distribution to be used to measure disctance to other point for removal of outlier points

Usage

1

Format

An sf POINT object


pbs-assess/hakedata documentation built on Jan. 16, 2021, 9:15 p.m.