fetch_spatial_catch_data: Run SQL code on the server database and return the records

Description Usage Arguments Value

View source: R/get-spatial-catch-data.R

Description

Run SQL code on the server database and return the records

Usage

1
fetch_spatial_catch_data(type, overwrite_file = FALSE)

Arguments

type

One of 'ft', 'ss', or 'jv' for Freezer Trawler, Shoreside, and Joint Venture respectively

overwrite_file

If TRUE, and the function has been run before and an rds file generated, overwrite this. If FALSE, run the SQL and generate the file.

Value

A data frame of the records returned for the SQL code given


pbs-assess/hakedata documentation built on Jan. 16, 2021, 9:15 p.m.