get_catch: Get the catch data from the DMP and LOGS data frames

Description Usage Arguments Value

Description

Get the catch data from the DMP and LOGS data frames

Usage

1

Arguments

d

a list of length 2 with elements being (1) The Dockside Monitoring Program data frame as extracted by load_catch_data() and (2) the Logbook data frame as extracted by load_catch_data()

type

one of "ft", "ss", or "jv" for Freezer Trawler, Shoreside, or Joint Venture respectively

Value

A data frame containing only data for the type given by type


pbs-assess/hakedata documentation built on Jan. 16, 2021, 9:15 p.m.