get_depth_by_year: Get depth data by year and calculate boxplot stats on it....

Description Usage Arguments Value Examples

View source: R/get-depths.R

Description

Get depth data by year and calculate boxplot stats on it. This writes a CSV file containing the output

Usage

1
get_depth_by_year(d, type = "bottom", yrs = NULL, min_depth_cutoff = 50/1.8288)

Arguments

d

Output from load_spatial_catch_data()

type

One of "bottom" or "gear" for depth type

yrs

A vector of years to include. If NULL, all years in the data will be included

min_depth_cutoff

The depth for which to remove data. In fasthoms. All data shallower than this will be removed. This applies to both type 'bottom' and 'gear'

Value

Invisibly - A tibble containing year and depth record stats

Examples

1
2
d_ss <- load_spatial_catch_data("ss")
gear_depth_ss <- get_depth_by_year(d_ss, "gear")

pbs-assess/hakedata documentation built on Jan. 16, 2021, 9:15 p.m.