load_catch_data: Loads data from RDS files found in the data directory

Description Usage Arguments Value

View source: R/get-catch-data.R

Description

The function fetch_catch_data() must be run first to extract the data from the database into RDS files

Usage

1
load_catch_data(min_date = as.Date("2007-04-01"))

Arguments

min_date

Earliest date to include in the data returned

Value

A list of three dataframes, [[1]] for the DMP data, [[2]] for the LOGS data, and [[3]] for the area 4B data which were not included. [[3]] is returned as a convenience for you to see if any other data from area 4B should be included


pbs-assess/hakedata documentation built on Jan. 16, 2021, 9:15 p.m.