plot_lengths: Plot length distributions as histograms

Description Usage Arguments Value

View source: R/plot-data.R

Description

Plot length distributions as histograms

Usage

1
2
3
4
5
6
7
plot_lengths(
  yrs = NA,
  bin_width = 5,
  xlim = c(NA, NA),
  alpha = 0.6,
  legend_loc = "inside"
)

Arguments

yrs

Which years to include in the data to plot. If NA, all years in the Years column will be used

bin_width

See ggplot2::geom_histogram()

xlim

Limits for the x-axis. For c(NA, NA), plot will extend to limits of data

alpha

Transparency of fill from 0 - 1

legend_loc

Where to place legend "inside" or "outside" the frame of the plot

Value

A ggplot2 object


pbs-assess/hakedata documentation built on Jan. 16, 2021, 9:15 p.m.