remove_trip_data: Remove some trip types from a data frame

Description Usage Arguments Value

Description

Remove some trip types from a data frame

Usage

1
remove_trip_data(d, types, trip_type_colname)

Arguments

d

A data frame containing the column trip_type_colname

types

A vector of strings to grep for in the trip_type_colname column for removal

trip_type_colname

The column name containing the trip type strings

Value

A data frame with the data removed for the trip types


pbs-assess/hakedata documentation built on Jan. 16, 2021, 9:15 p.m.