Description Usage Arguments Value
Summarize the numbers of lengths, weights, ages, sample_weights, and catch_weights in the sample data
1 2 3 4 | sample_summary(
d = readRDS(here("data", sample_data_raw_file)),
vessel_filter = NULL
)
|
d |
A dataframe as extracted using |
vessel_filter |
If NULL, no filter. If "ft", then freezer trawlers as defined in this package. If "ss", then Shoreside vessels as defined in this package |
A list of two dataframes, the first summarized by year and the second sampled by sample_id and year
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.