strip_lines: Strip header lines of LOGBOOK file

Description Usage Arguments

Description

Search the file for the first occurance of the line starting with 'LOGBOOK' and remove it, and any following blank lines leaving only the column headers and data. Overwrite the file with this.

Usage

1

Arguments

file

filename (csv file)


pbs-assess/hakedata documentation built on Jan. 16, 2021, 9:15 p.m.