Description Usage Arguments Value
View source: R/get-spatial-catch-data.R
This function converts all supplied data frames into a single sf data frame. It also
removes points found on land or way out of the fishing area. The Fishing IDs (FIDs) for
this filtration were found using mapview::mapview().
1 |
... |
Dataframes to merge. They must all have the columns |
a spatial data frame as described in the sf package
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.