An sf class POINT which represents a point at the lower rightmost part of the fishery distribution to be used to measure disctance to other point for removal of outlier points
1 |
An sf POINT object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.