Description Usage Arguments Value
View source: R/get-spatial-catch-data.R
Run SQL code on the server database and return the records
1 | fetch_spatial_catch_data(type, overwrite_file = FALSE)
|
type |
One of 'ft', 'ss', or 'jv' for Freezer Trawler, Shoreside, and Joint Venture respectively |
overwrite_file |
If TRUE, and the function has been run before and an rds file generated, overwrite this. If FALSE, run the SQL and generate the file. |
A data frame of the records returned for the SQL code given
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.