Description Usage Arguments Value
Get the catch data from the DMP and LOGS data frames
1 |
d |
a list of length 2 with elements being (1) The Dockside Monitoring Program
data frame as extracted by |
type |
one of "ft", "ss", or "jv" for Freezer Trawler, Shoreside, or Joint Venture respectively |
A data frame containing only data for the type given by type
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.