Description Usage Arguments Value Examples
Get depth data by year and calculate boxplot stats on it. This writes a CSV file containing the output
1 | get_depth_by_year(d, type = "bottom", yrs = NULL, min_depth_cutoff = 50/1.8288)
|
d |
Output from |
type |
One of "bottom" or "gear" for depth type |
yrs |
A vector of years to include. If NULL, all years in the data will be included |
min_depth_cutoff |
The depth for which to remove data. In fasthoms. All data shallower than this
will be removed. This applies to both |
Invisibly - A tibble containing year and depth record stats
1 2 | d_ss <- load_spatial_catch_data("ss")
gear_depth_ss <- get_depth_by_year(d_ss, "gear")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.