Description Usage Arguments Value
View source: R/get-catch-data.R
The function fetch_catch_data() must be run first to extract the data from the database into RDS files
1 | load_catch_data(min_date = as.Date("2007-04-01"))
|
min_date |
Earliest date to include in the data returned |
A list of three dataframes, [[1]] for the DMP data, [[2]] for the LOGS data, and [[3]] for the area 4B
data which were not included. [[3]] is returned as a convenience for you to see if any other data from area 4B
should be included
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.