Description Usage Arguments Value
Plot depth boxplots by year (catchdate) or histograms for a single year
1 2 3 4 5 6 7 8 9 10 11 12 13 |
d |
The data frame as returned by the spatial SQL queries found in this in
the variable |
plot_type |
Type of plot, one of 'hist' or 'box' |
depth_type |
Type of depth to plot: 'bottom' or 'gear'. |
fishery_type |
One of NA, 'ft', 'ss', or 'jv'. If NA, all fisheries will be plotted against one another, if one of the others, that will be filtered before plotting |
depth_max |
Maximum depth. Remove records with depth greater than this. IF |
bin_width |
See |
xlim |
Limits for the x-axis. For c(NA, NA), plot will extend to limits of data |
alpha |
Transparency of fill from 0 - 1 |
show_legend |
Logical for inclusion of legend |
legend_loc |
Where to place legend "inside" or "outside" the frame of the plot |
A ggplot2 object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.