Description Usage Arguments Value
Remove some trip types from a data frame
1 | remove_trip_data(d, types, trip_type_colname)
|
d |
A data frame containing the column |
types |
A vector of strings to grep for in the |
trip_type_colname |
The column name containing the trip type strings |
A data frame with the data removed for the trip types
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.