Search the file for the first occurance of the line starting with 'LOGBOOK' and remove it, and any following blank lines leaving only the column headers and data. Overwrite the file with this.
1 |
file |
filename (csv file) |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.